
intrinsic ParametrizeDelPezzo8(I::RngMPol: statisticsFile := "") -> SeqEnum
{ find a parametrization of Del Pezzo surface of degree 8
  given by a homogeneous ideal}

  require (#Basis(I) gt 0): "Nontrivial ideal expected.";
  R := Parent(Basis(I)[1]);
  require (CoefficientRing(R) eq Rationals()): "A variety defined over rationals expected.";
  require (IsHomogeneous(I)): 
    "A projective variety should be defined by a homogeneous ideal.";
  require (Rank(R) eq 9): "A variety in 8-dimensional projective space expected.";
  for i := 1 to #Basis(I) do
    require (TotalDegree(Basis(I)[i]) eq 2): "A variety defined by quadratic forms expected.";
  end for;

  //  ######  begin write statistics  ######
  if not (statisticsFile eq "") then
    Write(statisticsFile, "FindLieAlgebra time:");
    t := Cputime();
  end if;
  //  ######  end write statistics  ######

  print "Lie algebra precomputed";
  Lrep, L := FindLieAlgebra(I);
  if (Dimension(L) ne 6) then
    print "The variety is not Del Pezzo surface of degree 8";
    print "  - the Lie algebra does not have the correct dimension";
    return [ ];
  end if;

  //  ######  begin write statistics  ######
  if not (statisticsFile eq "") then
    Write(statisticsFile, Cputime(t));

    cf_max := 0;
    for i := 1 to 6 do
      for j := 1 to 6 do
        if (i ne j) then
          cf := Eltseq(L ! Basis(L)[i]*Basis(L)[j]);
          for j := 1 to #cf do
            cf[j] := Abs(cf[j]);
          end for;
          for j := 1 to #cf do
            if (cf[j] ne 0) then
              cf_max := Max([cf_max, 1+Floor(Log(10, Numerator(cf[j]))), 
                                     1+Floor(Log(10, Denominator(cf[j])))]);
            end if;
          end for;
        end if;
      end for;
    end for;
    Write(statisticsFile, "Structure constants of the Lie algebra,");
    Write(statisticsFile, "  maximal number of digits in num/denom:");
    Write(statisticsFile, cf_max);
  end if;
  //  ######  end write statistics  ######

  b, ls := HasLeviSubalgebra(L);

  if b then 
    if (Dimension(ls) eq 3) then
      return ParametrizeBlowup(I: precomputedLie := true, pLrep := Lrep, pL := L);
    elif (Dimension(ls) eq 6) then
      dsd := DirectSumDecomposition(L);
      if (#dsd eq 2) then
        return ParametrizeAnticanonicalP1xP1(I: precomputedLie := true, pLrep := Lrep, pL := L);
      elif (#dsd eq 1) then
        return ParametrizeAnticanonicalSphere(I: precomputedLie := true, pLrep := Lrep, pL := L);
      end if;
    end if;
  end if;

  print "The variety is not Del Pezzo surface of degree 8";
  print "  - the Lie algebra does not have the expected structure.";
  return [ ];

end intrinsic;

